@@ -3,6 +3,7 @@ from __future__ import annotations
 import os
 import pretty_errors
 import rich
+from rich import print
 from typing import Literal, Tuple
 from pathlib import Path
 import datetime
@@ -109,14 +110,12 @@ class Cli:
                 print(f"警告: 无法加载配置文件 {config_path}: {e}")
                 continue
         
-        if loaded_from:
-            print(f"已加载配置文件: {loaded_from}")
-        else:
-            print(f"未找到配置文件，使用默认配置。搜索路径:")
-            for path in config_paths[:3]:  # 只显示前3个最常用的路径
-                print(f"  - {path}")
+        if not loaded_from:
+            print(f"以下路径中未找到配置文件。搜索路径:")
+            for path in config_paths:  # 只显示前3个最常用的路径
+                print(f"  - {path.resolve()}")
         
-        print("请执行 sparrow init-config 初始化配置文件")
+            print("请执行 `sparrow init-config` 初始化配置文件")
         
         return loaded_config
 
@@ -165,6 +164,7 @@ mllm:
   
   # API 密钥
   api_key: "EMPTY"
+
 """
         
         try:
