@@ -1,3 +1,5 @@
+import cv2
+import numpy as np
 import asyncio
 import base64
 import os
@@ -226,6 +228,9 @@ async def encode_to_base64(
     return result
 
 
+from sparrow import MeasureTime
+mt = MeasureTime()
+
 async def encode_image_to_base64(
     image_source,
     session: aiohttp.ClientSession,
@@ -250,6 +255,7 @@ async def encode_image_to_base64(
         Base64 encoded string (with optional MIME prefix)
     """
     # Get image as PIL Image object
+    mt.start()
     if isinstance(image_source, Image.Image):
         image = image_source
     else:
@@ -262,38 +268,23 @@ async def encode_image_to_base64(
         )
 
     # Make a copy of the image to avoid modifying the original
-    image = image.copy()
+    # image = image.copy()
 
     # Store original format
     original_format = image.format or "PNG"
 
     # Resize image based on provided constraints
-    if max_width and max_height:
-        # Use thumbnail to maintain aspect ratio while fitting within max dimensions
-        image.thumbnail((max_width, max_height), LANCZOS)
-    elif max_width:
-        # Use thumbnail with unlimited height
-        image.thumbnail((max_width, float("inf")), LANCZOS)
-    elif max_height:
-        # Use thumbnail with unlimited width
-        image.thumbnail((float("inf"), max_height), LANCZOS)
-
-    # Handle max_pixels constraint (after other resizing to avoid unnecessary work)
-    if max_pixels and (image.width * image.height > max_pixels):
-        # Calculate the ratio needed to get to max_pixels
-        ratio = (max_pixels / (image.width * image.height)) ** 0.5
-        # Use thumbnail to maintain aspect ratio
-        target_width = int(image.width * ratio)
-        target_height = int(image.height * ratio)
+    target_width, target_height = get_target_size(image, max_width, max_height, max_pixels)
+    if target_width < image.width or target_height < image.height:
         image.thumbnail((target_width, target_height), LANCZOS)
 
-    # Convert processed image to base64
-    buffer = BytesIO()
     mime_type = f"image/{original_format.lower()}"
-    image.save(buffer, format=original_format)
-    buffer.seek(0)
 
-    base64_data = base64.b64encode(buffer.getvalue()).decode("utf-8")
+    # Convert processed image to base64
+    cv_img = cv2.cvtColor(np.array(image), cv2.COLOR_RGB2BGR)
+    # 直接编码为所需格式（可添加压缩参数）
+    _, buffer = cv2.imencode(f'.{original_format.lower()}', cv_img)
+    base64_data = base64.b64encode(buffer).decode("utf-8")
 
     if return_with_mime:
         return f"data:{mime_type};base64,{base64_data}"
@@ -624,3 +615,24 @@ def save_image_with_format(image: Image.Image, path: Path):
             image = image.convert('RGB')
             image.save(path, format=target_format)
 
+
+def get_target_size(image, max_width, max_height, max_pixels):
+    width, height = image.width, image.height
+    
+    # 应用最大宽度/高度限制
+    if max_width and width > max_width:
+        height = int(height * max_width / width)
+        width = max_width
+    
+    if max_height and height > max_height:
+        width = int(width * max_height / height)
+        height = max_height
+    
+    # 应用最大像素限制
+    if max_pixels and (width * height > max_pixels):
+        ratio = (max_pixels / (width * height)) ** 0.5
+        width = int(width * ratio)
+        height = int(height * ratio)
+    
+    return width, height
+
